@@ -1,6 +1,6 @@
 /* -*-mode:c++; c-file-style: "gnu";-*- */
 /*
- *  $Id: MStreamable.cpp,v 1.9 2007/07/02 18:48:19 sebdiaz Exp $
+ *  $Id: MStreamable.cpp,v 1.10 2014/04/23 20:55:09 sebdiaz Exp $
  *
  *  Copyright (C) 1996 - 2004 Stephen F. Booth <sbooth@gnu.org>
  *                       2007 Sebastien DIAZ <sebastien.diaz@gmail.com>
@@ -25,7 +25,7 @@
 #  pragma implementation
 #endif
 
-#include "cgicc/MStreamable.h"
+#include "MStreamable.h"
 
 // ============================================================
 // Class MStreamable
